@@ -3,14 +3,14 @@
  * Author: Sascha
  */
 #include <QtGui/QApplication>
-#include "form.h"
+#include "mainwindow.h"
 
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
     QCoreApplication::setOrganizationName("STM Software");
     QCoreApplication::setApplicationName("Countdown Timer");
-    Form f;
-    f.show();
+    MainWindow w;
+    w.show();
     return a.exec();
 }
